import click
import requests
from .api import LmsApi
from tritise import Tritise

def gotify(url, token, title, message, prio=2):
    resp = requests.post(url,
        params = {'token': token},
        json={
            "message": message,
            "priority": prio,
            "title": title
        }
    )

@click.command()
@click.option('--database', '-d', default='lms-prepaid.sqlite', envvar='LMS_PREPAID_DATABASE')
@click.option('--card', '-c', required=True, help='The number of the prepaid card (AB-CDE-123456-X)', envvar='LMS_PREPAID_CARD')
@click.option('--quiet', '-q', help='Only print the amount, nothing else', is_flag=True)
@click.option('--currency/--no-currency', ' /-R', help='Print the currency the amount is in', default=True)
@click.option('--gotify-url', '-g', default=None, envvar='LMS_PREPAID_GOTIFY_URL')
@click.option('--gotify-token', '-k', default=None, envvar='LMS_PREPAID_GOTIFY_TOKEN')
@click.option('--gotify-prio', '-o', default=2, envvar='LMS_PREPAID_GOTIFY_PRIO')
@click.option('--dump-responses', '-u', default=False, is_flag=True)
def query(database, card, quiet, currency, dump_responses, gotify_url, gotify_token, gotify_prio):
    t = Tritise(filename=database)
    api = LmsApi(card)
    api.set_dump_responses(dump_responses)
    if (not quiet):
        print('Querying data for card: %s' % card)
    credit = api.get_credit()
    notify_change = gotify_token and gotify_url
    if notify_change:
        last_credit = t.last()
        if not last_credit or (last_credit.value != credit.amount):
            gotify(gotify_url,
                   gotify_token,
                   'Prepaid card credit changed', 'New credit: %.2f' % credit.amount,
                   gotify_prio)
    t.add(credit.amount)
    output = '%.2f' % credit.amount
    if (currency):
        output = output + ' ' + credit.currency
    print(output)

if __name__ == '__main__':
    query()


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['lms_prepaid']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.0,<8.0', 'requests>=2.22.0,<3.0.0', 'tritise>=0.1.0,<0.2.0']

entry_points = \
{'console_scripts': ['lms-prepaid = lms_prepaid.lms_prepaid:query']}

setup_kwargs = {
    'name': 'lms-prepaid',
    'version': '0.1.0',
    'description': 'A script to query Last Mile Solutions prepaid card values',
    'long_description': None,
    'author': 'asmw',
    'author_email': 'asmw@asmw.org',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



import requests

APP_API_ENDPOINT='https://evc-net.com/api/app'
DEFAULT_DEVICE_ID='1233456789'
DEFAULT_APPVERSION='4.1.2'

class InvalidRequest(Exception):
    pass

class InvalidCreditResponse(Exception):
    pass

class LmsCredit(object):
    amount = 0
    currency = None

    def __init__(self, amount, currency):
        self.amount = float(amount)
        self.currency = currency

class LmsApi(object):
    def __init__(self, card_id, device_id = DEFAULT_DEVICE_ID, app_version = DEFAULT_APPVERSION):
        self._card_id = card_id
        self._device_id = device_id
        self._app_version = app_version
        self._card_registration_code = None # What is this? How to use
        self._dump_responses = False

    def set_dump_responses(self, dump):
        self._dump_responses = dump

    def _post_action(self, action, additional_parameters = None):
        parameters = {
            'deviceId': self._device_id,
            'version': self._app_version,
            'cardRegistrationCode': self._card_registration_code,
            'cardExternalId': self._card_id,
        }
        if additional_parameters:
            for key, value in additional_parameters:
                parameters[key] = value
        data = requests.post(APP_API_ENDPOINT, json={
                    'action': action,
                    'parameters': parameters
               }).json()
        if (self._dump_responses):
            print(data)
        if data['status'] == 'invalidRequest':
            raise InvalidRequest()
        return data

    def get_credit(self):
        data = self._post_action('getCredit')
        if not 'amount' in data or not 'currency' in data:
            raise InvalidCreditResponse()
        return LmsCredit(data['amount'], data['currency'])
